@@ -13,7 +13,7 @@ This is the main script that get called on the command line
 import sys
 import argparse
 #from __init__ import __version__
-from align import align
+from .align import align
 
 #----------------------------------------------------------------------------#
 # These are the functions that actually do the computational steps
@@ -23,11 +23,11 @@ def parse_align(args):
     :type args: dict
     """
     align(
-        args.file,
-        args.organism,
-        args.technology,
-        args.threads,
-        args.memory,
+        args.f,
+        args.o,
+        args.x,
+        threads=args.t,
+        memory=args.m,
         )
 #----------------------------------------------------------------------------#
 # Here are all the commands that are give to scGP so you can run scGP COMMAND
@@ -80,6 +80,20 @@ def setup_align_args(parser, parent):
         type=str,
         required=True
     )
+    parser_ref.add_argument(
+        '-t',
+        metavar='THREADS',
+        help='Number of threads to use (default: 8)',
+        type=int,
+        default=8
+    )
+    parser_ref.add_argument(
+        '-m',
+        metavar='MEMORY',
+        help='Maximum memory used (default: 4G)',
+        type=str,
+        default='4G'
+    )
     
     return parser_ref
 
